Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(139)

Unified Diff: chrome/browser/sync/engine/verify_updates_command.h

Issue 386030: Relieve SyncerSession,SyncCycleState, SyncProcessState, SyncerSession, Syncer... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/engine/verify_updates_command.h
===================================================================
--- chrome/browser/sync/engine/verify_updates_command.h (revision 32731)
+++ chrome/browser/sync/engine/verify_updates_command.h (working copy)
@@ -8,9 +8,8 @@
#include "base/basictypes.h"
#include "chrome/browser/sync/engine/syncer_command.h"
-#include "chrome/browser/sync/engine/syncer_session.h"
#include "chrome/browser/sync/engine/syncproto.h"
-#include "chrome/browser/sync/util/sync_types.h"
+#include "chrome/browser/sync/engine/syncer_types.h"
namespace syncable {
class WriteTransaction;
@@ -19,13 +18,15 @@
namespace browser_sync {
// Verifies the response from a GetUpdates request. All invalid updates will be
// noted in the SyncerSession after this command is executed.
class VerifyUpdatesCommand : public SyncerCommand {
public:
VerifyUpdatesCommand();
virtual ~VerifyUpdatesCommand();
- virtual void ExecuteImpl(SyncerSession* session);
+ // SyncerCommand implementation.
+ virtual void ExecuteImpl(sessions::SyncSession* session);
+
VerifyResult VerifyUpdate(syncable::WriteTransaction* trans,
const SyncEntity& entry);
private:
@@ -19,13 +18,15 @@
namespace browser_sync {
// Verifies the response from a GetUpdates request. All invalid updates will be
-// noted in the SyncerSession after this command is executed.
+// noted in the SyncSession after this command is executed.
class VerifyUpdatesCommand : public SyncerCommand {
public:
« no previous file with comments | « chrome/browser/sync/engine/update_applicator.cc ('k') | chrome/browser/sync/engine/verify_updates_command.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698